pub struct Affine<P: SWCurveConfig> { /* private fields */ }Expand description
Affine coordinates for a point on an elliptic curve in short Weierstrass
form, over the base field P::BaseField.
Implementations
Sourceimpl<P: SWCurveConfig> Affine<P>
impl<P: SWCurveConfig> Affine<P>
Sourcepub fn new(x: P::BaseField, y: P::BaseField) -> Self
pub fn new(x: P::BaseField, y: P::BaseField) -> Self
Constructs a group element from x and y coordinates. Performs checks to ensure that the point is on the curve and is in the right subgroup.
Sourcepub const fn new_unchecked(x: P::BaseField, y: P::BaseField) -> Self
pub const fn new_unchecked(x: P::BaseField, y: P::BaseField) -> Self
Constructs a group element from x and y coordinates.
Warning
Does not perform any checks to ensure the point is in the curve or is in the right subgroup.
pub const fn identity() -> Self
Sourcepub fn get_point_from_x_unchecked(
x: P::BaseField,
greatest: bool,
) -> Option<Self>
pub fn get_point_from_x_unchecked( x: P::BaseField, greatest: bool, ) -> Option<Self>
Attempts to construct an affine point given an x-coordinate. The point is not guaranteed to be in the prime order subgroup.
If and only if greatest is set will the lexicographically
largest y-coordinate be selected.
Sourcepub fn get_ys_from_x_unchecked(
x: P::BaseField,
) -> Option<(P::BaseField, P::BaseField)>
pub fn get_ys_from_x_unchecked( x: P::BaseField, ) -> Option<(P::BaseField, P::BaseField)>
Returns the two possible y-coordinates corresponding to the given x-coordinate.
The corresponding points are not guaranteed to be in the prime-order subgroup,
but are guaranteed to be on the curve. That is, this method returns None
if the x-coordinate corresponds to a non-curve point.
The results are sorted by lexicographical order.
This means that, if P::BaseField: PrimeField, the results are sorted as integers.
Sourcepub fn is_on_curve(&self) -> bool
pub fn is_on_curve(&self) -> bool
Checks if self is a valid point on the curve.
pub fn to_flags(&self) -> SWFlags
pub fn double_to_bucket(&self) -> Bucket<P>
Sourceimpl<P: SWCurveConfig> Affine<P>
impl<P: SWCurveConfig> Affine<P>
Sourcepub fn is_in_correct_subgroup_assuming_on_curve(&self) -> bool
pub fn is_in_correct_subgroup_assuming_on_curve(&self) -> bool
Checks if self is in the subgroup having order that equaling that of
P::ScalarField.