Bucket

Struct Bucket 

pub struct Bucket<P: SWCurveConfig> {
    pub x: P::BaseField,
    pub y: P::BaseField,
    pub zz: P::BaseField,
    pub zzz: P::BaseField,
}
Extended Jacobian coordinates for a point on an elliptic curve in short Weierstrass form, over the base field P::BaseField. This struct implements arithmetic via the extended Jacobian arithmetic outlined here: https://www.hyperelliptic.org/EFD/g1p/auto-shortw-xyzz.html

Fields

x: P::BaseField

X / ZZ projection of the affine X

y: P::BaseField

Y / ZZZ projection of the affine Y

zz: P::BaseField

Bucket multiplicative inverse. Will be 0 only at infinity.

zzz: P::BaseField

Bucket multiplicative inverse. Will be 0 only at infinity.

Implementations

Source

impl<P: SWCurveConfig> Bucket<P>

pub const ZERO: Self

pub const fn new_unchecked( x: P::BaseField, y: P::BaseField, zz: P::BaseField, zzz: P::BaseField, ) -> Self

Constructs a new group element without checking whether the coordinates specify a point in the subgroup.

pub fn is_zero(&self) -> bool

Checks whether self.z.is_zero().

pub fn double_in_place(&mut self)