pub struct Projective<P: SWCurveConfig> {
pub x: P::BaseField,
pub y: P::BaseField,
pub z: P::BaseField,
}Expand description
Jacobian coordinates for a point on an elliptic curve in short Weierstrass
form, over the base field P::BaseField. This struct implements arithmetic
via the Jacobian formulae.
Fields
x: P::BaseFieldX / Z^2 projection of the affine X
y: P::BaseFieldY / Z^3 projection of the affine Y
z: P::BaseFieldProjective multiplicative inverse. Will be 0 only at infinity.
Implementations
Sourceimpl<P: SWCurveConfig> Projective<P>
impl<P: SWCurveConfig> Projective<P>
Sourcepub const fn new_unchecked(
x: P::BaseField,
y: P::BaseField,
z: P::BaseField,
) -> Self
pub const fn new_unchecked( x: P::BaseField, y: P::BaseField, z: P::BaseField, ) -> Self
Constructs a new group element without checking whether the coordinates specify a point in the subgroup.