pub struct Bucket<P: SWCurveConfig> {
pub x: P::BaseField,
pub y: P::BaseField,
pub zz: P::BaseField,
pub zzz: P::BaseField,
}Expand description
Extended Jacobian coordinates for a point on an elliptic curve in short Weierstrass
form, over the base field P::BaseField.
This struct implements arithmetic via the extended Jacobian arithmetic outlined here:
https://www.hyperelliptic.org/EFD/g1p/auto-shortw-xyzz.html
Fields
x: P::BaseFieldX / ZZ projection of the affine X
y: P::BaseFieldY / ZZZ projection of the affine Y
zz: P::BaseFieldBucket multiplicative inverse. Will be 0 only at infinity.
zzz: P::BaseFieldBucket multiplicative inverse. Will be 0 only at infinity.
Implementations
Sourceimpl<P: SWCurveConfig> Bucket<P>
impl<P: SWCurveConfig> Bucket<P>
pub const ZERO: Self
Sourcepub const fn new_unchecked(
x: P::BaseField,
y: P::BaseField,
zz: P::BaseField,
zzz: P::BaseField,
) -> Self
pub const fn new_unchecked( x: P::BaseField, y: P::BaseField, zz: P::BaseField, zzz: P::BaseField, ) -> Self
Constructs a new group element without checking whether the coordinates specify a point in the subgroup.
pub fn double_in_place(&mut self)